from django.contrib import admin
from django.contrib.auth.admin import UserAdmin
from .models import CustomUser
from rest_framework_simplejwt.tokens import RefreshToken


class CustomUserAdmin(UserAdmin):
    model = CustomUser
    list_display = ('email', 'name', 'grade', 'is_active', 'is_staff', 'jwt_preview')
    list_filter = ('grade', 'is_active', 'is_staff')
    search_fields = ('email', 'name')
    ordering = ('email',)

    readonly_fields = ('created_at', 'last_login', 'jwt_preview')  # ✅ jwt_preview 추가

    fieldsets = (
        (None, {'fields': ('email', 'password')}),
        ('Personal Info', {'fields': ('name', 'grade')}),
        ('Permissions', {'fields': ('is_active', 'is_staff', 'is_superuser', 'groups', 'user_permissions')}),
        ('Important dates', {'fields': ('last_login', 'created_at')}),
        ('JWT Token Preview', {'fields': ('jwt_preview',)}),  # ✅ 별도 섹션으로 추가
    )

    add_fieldsets = (
        (None, {
            'classes': ('wide',),
            'fields': (
                'email', 'name', 'grade', 'password1', 'password2',
                'is_active', 'is_staff', 'is_superuser'
            ),
        }),
    )

    def jwt_preview(self, obj):
        try:
            refresh = RefreshToken.for_user(obj)
            access_token = str(refresh.access_token)
            return access_token[:30] + "..."  # ✅ 일부만 보여줌
        except Exception:
            return "N/A"

    jwt_preview.short_description = "JWT Access Preview"


admin.site.register(CustomUser, CustomUserAdmin)
